@@ -28,8 +28,8 @@
 #include "Mapper.hxx"
 #include "protocol/RangeArg.hxx"
 #include "fs/io/TextFile.hxx"
-#include "fs/io/FileOutputStream.hxx"
-#include "fs/io/BufferedOutputStream.hxx"
+#include "io/FileOutputStream.hxx"
+#include "io/BufferedOutputStream.hxx"
 #include "config/Data.hxx"
 #include "config/Option.hxx"
 #include "config/Defaults.hxx"
@@ -81,6 +81,9 @@ spl_valid_name(const char *name_utf8)
 	 */
 
 	return std::strchr(name_utf8, '/') == nullptr &&
+#ifdef _WIN32
+		std::strchr(name_utf8, '\\') == nullptr &&
+#endif
 		std::strchr(name_utf8, '\n') == nullptr &&
 		std::strchr(name_utf8, '\r') == nullptr;
 }
