@@ -34,6 +34,8 @@
 #include "system/Clock.hxx"
 #endif
 
+#include <fmt/format.h>
+
 #include <chrono>
 
 #ifndef _WIN32
@@ -97,19 +99,19 @@ db_stats_print(Response &r, const Database &db)
 	unsigned total_duration_s =
 		std::chrono::duration_cast<std::chrono::seconds>(stats.total_duration).count();
 
-	r.Format("artists: %u\n"
-		 "albums: %u\n"
-		 "songs: %u\n"
-		 "db_playtime: %u\n",
-		 stats.artist_count,
-		 stats.album_count,
-		 stats.song_count,
-		 total_duration_s);
+	r.Fmt("artists: {}\n"
+	      "albums: {}\n"
+	      "songs: {}\n"
+	      "db_playtime: {}\n",
+	      stats.artist_count,
+	      stats.album_count,
+	      stats.song_count,
+	      total_duration_s);
 
 	const auto update_stamp = db.GetUpdateStamp();
 	if (!IsNegative(update_stamp))
-		r.Format("db_update: %lu\n",
-			 (unsigned long)std::chrono::system_clock::to_time_t(update_stamp));
+		r.Fmt("db_update: {}\n",
+		      std::chrono::system_clock::to_time_t(update_stamp));
 }
 
 #endif
@@ -123,10 +125,10 @@ stats_print(Response &r, const Partition &partition)
 	const auto uptime = std::chrono::steady_clock::now() - start_time;
 #endif
 
-	r.Format("uptime: %u\n"
-		 "playtime: %lu\n",
-		 (unsigned)std::chrono::duration_cast<std::chrono::seconds>(uptime).count(),
-		 lround(partition.pc.GetTotalPlayTime().count()));
+	r.Fmt("uptime: {}\n"
+	      "playtime: {}\n",
+	      std::chrono::duration_cast<std::chrono::seconds>(uptime).count(),
+	      lround(partition.pc.GetTotalPlayTime().count()));
 
 #ifdef ENABLE_DATABASE
 	const Database *db = partition.instance.GetDatabase();
