@@ -126,6 +126,18 @@ Directory::LookupTargetSong(std::string_view _target) noexcept
 	return lr.directory->FindSong(lr.rest);
 }
 
+void
+Directory::ClearInPlaylist() noexcept
+{
+	assert(holding_db_lock());
+
+	for (auto &child : children)
+		child.ClearInPlaylist();
+
+	for (auto &song : songs)
+		song.in_playlist = false;
+}
+
 void
 Directory::PruneEmpty() noexcept
 {
