@@ -282,7 +282,7 @@ InotifyUpdate::InotifyCallback(int wd, unsigned mask,
 	    (mask & IN_ISDIR) != 0) {
 		/* a sub directory was changed: register those in
 		   inotify */
-		const Path root_path = root->name;
+		const auto root_path = root->name;
 
 		const auto path_fs = uri_fs.IsNull()
 			? root_path
@@ -293,6 +293,10 @@ InotifyUpdate::InotifyCallback(int wd, unsigned mask,
 	}
 
 	if ((mask & (IN_CLOSE_WRITE|IN_MOVE|IN_DELETE)) != 0 ||
+	    /* regular file or symlink was created; this check is only
+	       interesting for symlinks because regular files have
+	       usable content only after IN_CLOSE_WRITE */
+	    (mask & (IN_CREATE|IN_ISDIR)) == IN_CREATE ||
 	    /* at the maximum depth, we watch out for newly created
 	       directories */
 	    (directory.GetDepth() == max_depth &&
