@@ -20,6 +20,7 @@
 #include "config.h"
 #include "MikmodDecoderPlugin.hxx"
 #include "../DecoderAPI.hxx"
+#include "lib/fmt/PathFormatter.hxx"
 #include "tag/Handler.hxx"
 #include "fs/Path.hxx"
 #include "util/Domain.hxx"
@@ -61,9 +62,9 @@ mikmod_mpd_is_present()
 	return true;
 }
 
-static char drv_name[] = PACKAGE_NAME;
-static char drv_version[] = VERSION;
-static char drv_alias[] = PACKAGE;
+static constexpr char drv_name[] = PACKAGE_NAME;
+static constexpr char drv_version[] = VERSION;
+static constexpr char drv_alias[] = PACKAGE;
 
 static MDRIVER drv_mpd = {
 	nullptr,
@@ -126,9 +127,9 @@ mikmod_decoder_init(const ConfigBlock &block)
 		   DMODE_16BITS);
 
 	if (MikMod_Init(params)) {
-		FormatError(mikmod_domain,
-			    "Could not init MikMod: %s",
-			    MikMod_strerror(MikMod_errno));
+		FmtError(mikmod_domain,
+			 "Could not init MikMod: {}",
+			 MikMod_strerror(MikMod_errno));
 		return false;
 	}
 
@@ -155,8 +156,7 @@ mikmod_decoder_file_decode(DecoderClient &client, Path path_fs)
 	handle = Player_Load(path2, 128, 0);
 
 	if (handle == nullptr) {
-		FormatError(mikmod_domain,
-			    "failed to open mod: %s", path_fs.c_str());
+		FmtError(mikmod_domain, "failed to open mod: {}", path_fs);
 		return;
 	}
 
@@ -189,8 +189,7 @@ mikmod_decoder_scan_file(Path path_fs, TagHandler &handler) noexcept
 	MODULE *handle = Player_Load(path2, 128, 0);
 
 	if (handle == nullptr) {
-		FormatDebug(mikmod_domain,
-			    "Failed to open file: %s", path_fs.c_str());
+		FmtDebug(mikmod_domain, "Failed to open file: {}", path_fs);
 		return false;
 	}
 
