@@ -18,11 +18,11 @@
  */
 
 #include "SignalMonitor.hxx"
-#include "config.h"
+#include "event/Features.h"
 
 #ifndef _WIN32
 
-#include "SocketMonitor.hxx"
+#include "SocketEvent.hxx"
 #include "util/Manual.hxx"
 #include "system/Error.hxx"
 
@@ -37,6 +37,7 @@
 #endif
 
 #include <algorithm>
+#include <array>
 #include <cassert>
 #include <csignal>
 
@@ -44,33 +45,37 @@
 #include <pthread.h>
 #endif
 
-class SignalMonitor final : private SocketMonitor {
+class SignalMonitor final {
 #ifdef USE_SIGNALFD
 	SignalFD fd;
 #else
 	WakeFD fd;
 #endif
 
+	SocketEvent event;
+
 public:
 	explicit SignalMonitor(EventLoop &_loop)
-		:SocketMonitor(_loop) {
+		:event(_loop, BIND_THIS_METHOD(OnSocketReady)) {
 #ifndef USE_SIGNALFD
-		SocketMonitor::Open(SocketDescriptor(fd.Get()));
-		SocketMonitor::ScheduleRead();
+		event.Open(fd.GetSocket());
+		event.ScheduleRead();
 #endif
 	}
 
-	using SocketMonitor::GetEventLoop;
+	[[nodiscard]] auto &GetEventLoop() const noexcept {
+		return event.GetEventLoop();
+	}
 
 #ifdef USE_SIGNALFD
 	void Update(sigset_t &mask) noexcept {
-		const bool was_open = SocketMonitor::IsDefined();
+		const bool was_open = event.IsDefined();
 
 		fd.Create(mask);
 
 		if (!was_open) {
-			SocketMonitor::Open(SocketDescriptor(fd.Get()));
-			SocketMonitor::ScheduleRead();
+			event.Open(SocketDescriptor(fd.Get()));
+			event.ScheduleRead();
 		}
 	}
 #else
@@ -80,18 +85,18 @@ public:
 #endif
 
 private:
-	bool OnSocketReady(unsigned flags) noexcept override;
+	void OnSocketReady(unsigned flags) noexcept;
 };
 
 /* this should be enough - is it? */
 static constexpr unsigned MAX_SIGNAL = 64;
 
-static SignalHandler signal_handlers[MAX_SIGNAL];
+static std::array<SignalHandler, MAX_SIGNAL> signal_handlers;
 
 #ifdef USE_SIGNALFD
 static sigset_t signal_mask;
 #else
-static std::atomic_bool signal_pending[MAX_SIGNAL];
+static std::array<std::atomic_bool, MAX_SIGNAL> signal_pending;
 #endif
 
 static Manual<SignalMonitor> monitor;
@@ -149,7 +154,7 @@ void
 SignalMonitorFinish() noexcept
 {
 #ifdef USE_SIGNALFD
-	std::fill_n(signal_handlers, MAX_SIGNAL, nullptr);
+	signal_handlers = {};
 #else
 	struct sigaction sa;
 	sa.sa_flags = 0;
@@ -163,7 +168,7 @@ SignalMonitorFinish() noexcept
 		}
 	}
 
-	std::fill_n(signal_pending, MAX_SIGNAL, false);
+	std::fill(signal_pending.begin(), signal_pending.end(), false);
 #endif
 
 	monitor.Destruct();
@@ -195,7 +200,7 @@ SignalMonitorRegister(int signo, SignalHandler handler)
 #endif
 }
 
-bool
+void
 SignalMonitor::OnSocketReady(unsigned) noexcept
 {
 #ifdef USE_SIGNALFD
@@ -213,8 +218,6 @@ SignalMonitor::OnSocketReady(unsigned) noexcept
 		if (signal_pending[i].exchange(false))
 			signal_handlers[i]();
 #endif
-
-	return true;
 }
 
 #endif
