@@ -18,7 +18,6 @@
  */
 
 #include "ThreadInputStream.hxx"
-#include "CondHandler.hxx"
 #include "thread/Name.hxx"
 
 #include <cassert>
@@ -95,10 +94,12 @@ ThreadInputStream::ThreadFunc() noexcept
 				nbytes = ThreadRead(w.data, w.size);
 			} catch (...) {
 				postponed_exception = std::current_exception();
+				caller_cond.notify_one();
 				InvokeOnAvailable();
 				break;
 			}
 
+			caller_cond.notify_one();
 			InvokeOnAvailable();
 
 			if (nbytes == 0) {
@@ -136,8 +137,6 @@ ThreadInputStream::Read(std::unique_lock<Mutex> &lock,
 {
 	assert(!thread.IsInside());
 
-	CondInputStreamHandler cond_handler;
-
 	while (true) {
 		if (postponed_exception)
 			std::rethrow_exception(postponed_exception);
@@ -147,6 +146,14 @@ ThreadInputStream::Read(std::unique_lock<Mutex> &lock,
 			size_t nbytes = std::min(read_size, r.size);
 			memcpy(ptr, r.data, nbytes);
 			buffer.Consume(nbytes);
+
+			if (buffer.empty())
+				/* when the buffer becomes empty,
+				   reset its head and tail so the next
+				   write can fill the whole buffer and
+				   not just the part after the tail */
+				buffer.Clear();
+
 			wake_cond.notify_all();
 			offset += nbytes;
 			return nbytes;
@@ -155,8 +162,7 @@ ThreadInputStream::Read(std::unique_lock<Mutex> &lock,
 		if (eof)
 			return 0;
 
-		const ScopeExchangeInputStreamHandler h(*this, &cond_handler);
-		cond_handler.cond.wait(lock);
+		caller_cond.wait(lock);
 	}
 }
 
