@@ -28,12 +28,10 @@
 #include "lib/alsa/NonBlock.hxx"
 #include "lib/alsa/Error.hxx"
 #include "lib/alsa/Format.hxx"
-#include "../InputPlugin.hxx"
 #include "../AsyncInputStream.hxx"
 #include "event/Call.hxx"
 #include "config/Block.hxx"
 #include "util/Domain.hxx"
-#include "util/RuntimeError.hxx"
 #include "util/ASCII.hxx"
 #include "util/DivideString.hxx"
 #include "pcm/AudioParser.hxx"
@@ -236,10 +234,10 @@ AlsaInputStream::PrepareSockets() noexcept
 
 void
 AlsaInputStream::DispatchSockets() noexcept
-{
+try {
 	non_block.DispatchSockets(*this, capture_handle);
 
-	const std::lock_guard<Mutex> protect(mutex);
+	const std::scoped_lock<Mutex> protect(mutex);
 
 	auto w = PrepareWriteBuffer();
 	const snd_pcm_uframes_t w_frames = w.size / frame_size;
@@ -255,16 +253,17 @@ AlsaInputStream::DispatchSockets() noexcept
 		if (n_frames == -EAGAIN)
 			return;
 
-		if (Recover(n_frames) < 0) {
-			postponed_exception = std::make_exception_ptr(std::runtime_error("PCM error - stream aborted"));
-			InvokeOnAvailable();
-			return;
-		}
+		if (Recover(n_frames) < 0)
+			throw std::runtime_error("PCM error - stream aborted");
 	}
 
 	size_t nbytes = n_frames * frame_size;
 	CommitWriteBuffer(nbytes);
 }
+catch (...) {
+	postponed_exception = std::current_exception();
+	InvokeOnAvailable();
+}
 
 inline int
 AlsaInputStream::Recover(int err)
@@ -371,9 +370,14 @@ AlsaInputStream::ConfigureCapture(AudioFormat audio_format)
 		 period_size_min, period_size_max,
 		 period_time_min, period_time_max);
 
-	/* choose the maximum possible buffer_size ... */
-	snd_pcm_hw_params_set_buffer_size(capture_handle, hw_params,
-					  buffer_size_max);
+	/* choose the maximum buffer_time up to limit of 2 seconds ... */
+	unsigned buffer_time = buffer_time_max;
+	if (buffer_time > 2000000U)
+		buffer_time = 2000000U;
+	int direction = -1;
+	if ((err = snd_pcm_hw_params_set_buffer_time_near(capture_handle,
+				hw_params, &buffer_time, &direction)) < 0)
+		throw Alsa::MakeError(err, "Cannot set buffer time");
 
 	/* ... and calculate the period_size to have four periods in
 	   one buffer; this way, we get woken up often enough to avoid
@@ -381,7 +385,7 @@ AlsaInputStream::ConfigureCapture(AudioFormat audio_format)
 	snd_pcm_uframes_t buffer_size;
 	if (snd_pcm_hw_params_get_buffer_size(hw_params, &buffer_size) == 0) {
 		snd_pcm_uframes_t period_size = buffer_size / 4;
-		int direction = -1;
+		direction = -1;
 		if ((err = snd_pcm_hw_params_set_period_size_near(capture_handle,
 		                             hw_params, &period_size, &direction)) < 0)
 			throw Alsa::MakeError(err, "Cannot set period size");
