@@ -26,7 +26,7 @@
 #include "MultipleOutputs.hxx"
 #include "Domain.hxx"
 #include "Log.hxx"
-#include "fs/io/BufferedOutputStream.hxx"
+#include "io/BufferedOutputStream.hxx"
 #include "util/StringCompare.hxx"
 
 #include <stdlib.h>
@@ -41,7 +41,7 @@ audio_output_state_save(BufferedOutputStream &os,
 {
 	for (unsigned i = 0, n = outputs.Size(); i != n; ++i) {
 		const auto &ao = outputs.Get(i);
-		const std::lock_guard<Mutex> lock(ao.mutex);
+		const std::scoped_lock<Mutex> lock(ao.mutex);
 
 		os.Format(AUDIO_DEVICE_STATE "%d:%s\n",
 			  ao.IsEnabled(), ao.GetName());
