@@ -471,6 +471,16 @@ try {
 		}
 
 		UINT32 write_in_frames = buffer_size_in_frames;
+		DWORD mode = 0;
+		AtScopeExit(&) {
+			render_client->ReleaseBuffer(write_in_frames, mode);
+
+			if (!started) {
+				Start(client);
+				started = true;
+			}
+		};
+
 		if (!is_exclusive) {
 			UINT32 data_in_frames =
 				GetCurrentPaddingFrames(client);
@@ -481,7 +491,6 @@ try {
 		}
 
 		BYTE *data;
-		DWORD mode = 0;
 
 		if (HRESULT result =
 		    render_client->GetBuffer(write_in_frames, &data);
@@ -489,15 +498,6 @@ try {
 			throw MakeHResultError(result, "Failed to get buffer");
 		}
 
-		AtScopeExit(&) {
-			render_client->ReleaseBuffer(write_in_frames, mode);
-
-			if (!started) {
-				Start(client);
-				started = true;
-			}
-		};
-
 		const UINT32 write_size = write_in_frames * frame_size;
 		UINT32 new_data_size = 0;
 		new_data_size = spsc_buffer.pop(data, write_size);
@@ -1026,7 +1026,7 @@ WasapiOutput::EnumerateDevices(IMMDeviceEnumerator &enumerator)
 			continue;
 
 		FmtNotice(wasapi_output_domain,
-			  "Device \"{}\" \"{}\"", i, name);
+			  "Device \"{}\" \"{}\"", i, name.c_str());
 	}
 }
 
