@@ -36,7 +36,7 @@ playlist::Stop(PlayerControl &pc) noexcept
 
 	assert(current >= 0);
 
-	FormatDebug(playlist_domain, "stop");
+	LogDebug(playlist_domain, "stop");
 	pc.LockStop();
 	queued = -1;
 	playing = false;
