@@ -26,10 +26,14 @@
 #include "fs/NarrowPath.hxx"
 #include "pcm/AudioParser.hxx"
 #include "pcm/AudioFormat.hxx"
+#include "util/OptionDef.hxx"
+#include "util/OptionParser.hxx"
 #include "util/StringBuffer.hxx"
 #include "util/RuntimeError.hxx"
 #include "util/ScopeExit.hxx"
+#include "util/StaticFifoBuffer.hxx"
 #include "util/PrintException.hxx"
+#include "LogBackend.hxx"
 
 #include <cassert>
 #include <memory>
@@ -39,6 +43,51 @@
 #include <stdlib.h>
 #include <stdio.h>
 
+struct CommandLine {
+	FromNarrowPath config_path;
+
+	const char *output_name = nullptr;
+
+	AudioFormat audio_format{44100, SampleFormat::S16, 2};
+
+	bool verbose = false;
+};
+
+enum Option {
+	OPTION_VERBOSE,
+};
+
+static constexpr OptionDef option_defs[] = {
+	{"verbose", 'v', false, "Verbose logging"},
+};
+
+static CommandLine
+ParseCommandLine(int argc, char **argv)
+{
+	CommandLine c;
+
+	OptionParser option_parser(option_defs, argc, argv);
+	while (auto o = option_parser.Next()) {
+		switch (Option(o.index)) {
+		case OPTION_VERBOSE:
+			c.verbose = true;
+			break;
+		}
+	}
+
+	auto args = option_parser.GetRemaining();
+	if (args.size < 2 || args.size > 3)
+		throw std::runtime_error("Usage: run_output CONFIG NAME [FORMAT] <IN");
+
+	c.config_path = args[0];
+	c.output_name = args[1];
+
+	if (args.size > 2)
+		c.audio_format = ParseAudioFormat(args[2], false);
+
+	return c;
+}
+
 static std::unique_ptr<AudioOutput>
 LoadAudioOutput(const ConfigData &config, EventLoop &event_loop,
 		const char *name)
@@ -57,14 +106,19 @@ LoadAudioOutput(const ConfigData &config, EventLoop &event_loop,
 	if (plugin == nullptr)
 		throw FormatRuntimeError("No such audio output plugin: %s",
 					 plugin_name);
+#include "util/OptionDef.hxx"
+#include "util/OptionParser.hxx"
 
 	return std::unique_ptr<AudioOutput>(ao_plugin_init(event_loop, *plugin,
 							   *block));
 }
 
 static void
-run_output(AudioOutput &ao, AudioFormat audio_format)
+RunOutput(AudioOutput &ao, AudioFormat audio_format,
+	  FileDescriptor in_fd)
 {
+	in_fd.SetBinaryMode();
+
 	/* open the audio output */
 
 	ao.Enable();
@@ -76,65 +130,62 @@ run_output(AudioOutput &ao, AudioFormat audio_format)
 	fprintf(stderr, "audio_format=%s\n",
 		ToString(audio_format).c_str());
 
-	size_t frame_size = audio_format.GetFrameSize();
+	const size_t in_frame_size = audio_format.GetFrameSize();
 
 	/* play */
 
-	size_t length = 0;
-	char buffer[4096];
+	StaticFifoBuffer<std::byte, 4096> buffer;
+
 	while (true) {
-		if (length < sizeof(buffer)) {
-			ssize_t nbytes = read(0, buffer + length,
-					      sizeof(buffer) - length);
+		{
+			const auto dest = buffer.Write();
+			assert(!dest.empty());
+
+			ssize_t nbytes = in_fd.Read(dest.data, dest.size);
 			if (nbytes <= 0)
 				break;
 
-			length += (size_t)nbytes;
+			buffer.Append(nbytes);
 		}
 
-		size_t play_length = (length / frame_size) * frame_size;
-		if (play_length > 0) {
-			size_t consumed = ao.Play(buffer, play_length);
+		auto src = buffer.Read();
+		assert(!src.empty());
 
-			assert(consumed <= length);
-			assert(consumed % frame_size == 0);
+		src.size -= src.size % in_frame_size;
+		if (src.empty())
+			continue;
 
-			length -= consumed;
-			memmove(buffer, buffer + consumed, length);
-		}
+		size_t consumed = ao.Play(src.data, src.size);
+
+		assert(consumed <= src.size);
+		assert(consumed % in_frame_size == 0);
+
+		buffer.Consume(consumed);
 	}
+
+	ao.Drain();
 }
 
 int main(int argc, char **argv)
 try {
-	if (argc < 3 || argc > 4) {
-		fprintf(stderr, "Usage: run_output CONFIG NAME [FORMAT] <IN\n");
-		return EXIT_FAILURE;
-	}
-
-	const FromNarrowPath config_path = argv[1];
-
-	AudioFormat audio_format(44100, SampleFormat::S16, 2);
+	const auto c = ParseCommandLine(argc, argv);
+	SetLogThreshold(c.verbose ? LogLevel::DEBUG : LogLevel::INFO);
 
 	/* read configuration file (mpd.conf) */
 
-	const auto config = AutoLoadConfigFile(config_path);
+	const auto config = AutoLoadConfigFile(c.config_path);
 
 	EventThread io_thread;
 	io_thread.Start();
 
 	/* initialize the audio output */
 
-	auto ao = LoadAudioOutput(config, io_thread.GetEventLoop(), argv[2]);
-
-	/* parse the audio format */
-
-	if (argc > 3)
-		audio_format = ParseAudioFormat(argv[3], false);
+	auto ao = LoadAudioOutput(config, io_thread.GetEventLoop(),
+				  c.output_name);
 
 	/* do it */
 
-	run_output(*ao, audio_format);
+	RunOutput(*ao, c.audio_format, FileDescriptor(STDIN_FILENO));
 
 	/* cleanup and exit */
 
